==> connect-esi-0.0.4.tgz: package/lib/connect-esi.js <==
(function() {
  var http, querystring, url;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  http = require('http');
  url = require('url');
  querystring = require('querystring');
  exports.setupESI = function() {
    var handleESI;
    return handleESI = function(req, res, next) {
      var end, endWait, write;
      endWait = false;
      write = res.write;
      res.write = function(chunk, encoding) {
        var content_type, esiProcessor;
        res.write = write;
        content_type = (res._headers != null) && (res._headers['content-type'] != null) ? res._headers['content-type'] : 'text/plain';
        if (content_type.indexOf('text') !== -1) {
          console.log("\nres.write\nrequest.url: " + req.url + " content-type: " + content_type);
          endWait = true;
          esiProcessor = new exports.processESI(chunk, function(err, chunk) {
            var _ref;
            res.writeHead((_ref = res.statusCode) != null ? _ref : 200, {
              'Content-Length': chunk.length,
              'Content-Type': content_type
            });
            endWait = false;
            return res.write(chunk, encoding);
          });
          esiProcessor.request = req.headers;
          esiProcessor.request.url = url.parse('http://' + req.headers['host'] + req.url, true);
          return esiProcessor.execute();
        } else {
          return res.write(chunk, encoding);
        }
      };
      end = res.end;
      res.end = function(data, encoding) {
        res.end = end;
        if (data) {
          res.write(data, encoding);
        }
        if (endWait !== true) {
          return res.end();
        }
      };
      return next();
    };
  };
  exports.processESI = function(data, callback) {
    this.data = data.toString();
    this.callback = callback;
    this.request = [];
    this.request['url'] = url.parse('http://localhost:5678');
    this.execute = function() {
      var esi_tags, k, src_vars, _results;
      console.log("Searching for ESIs...");
      esi_tags = this.searchESI(this.data);
      console.log("Found " + esi_tags.length + " ESIs");
      if (esi_tags.length !== 0) {
        _results = [];
        for (k in esi_tags) {
          src_vars = this.processESIvars(esi_tags[k]);
          console.log("Fetching ESI '" + esi_tags[k] + "'");
          _results.push(this.fetchESI([esi_tags[k], src_vars], __bind(function(src, status, body) {
            var remaining;
            console.log("Fetch ESI '" + src[1] + "' returned status " + status);
            if (status !== 200) {
              body = '';
            }
            console.log("ESI tag subsitution for '" + src[0] + "'");
            remaining = this.subESI(src[0], body);
            console.log(remaining + " remaining ESIs");
            if (remaining === 0) {
              console.log("Display Data\n");
              return this.callback(false, this.data);
            }
          }, this)));
        }
        return _results;
      } else {
        console.log("Display Data\n");
        return this.callback(false, this.data);
      }
    };
    this.searchESI = function(data) {
      var esi_tags, k, match, re, _ref;
      re = new RegExp('<esi[^>]* src=("[^>"]+"|\'[^>\']+\')[^>]*>(</esi[^>]*>)?', 'gi');
      esi_tags = data.match(re);
      for (k in esi_tags) {
        re = new RegExp(' src=("(.*?)"|\'(.*?)\')');
        match = esi_tags[k].match(re);
        esi_tags[k] = (_ref = match[2]) != null ? _ref : match[3];
      }
      return esi_tags != null ? esi_tags : [];
    };
    this.fetchESI = function(src, callback) {
      var options, uri, _ref, _ref2, _ref3, _ref4, _ref5;
      if (!(src instanceof Array)) {
        src = [src, src];
      }
      uri = url.parse(src[1]);
      options = {
        host: (_ref = uri.hostname) != null ? _ref : this.request.url.hostname,
        port: (_ref2 = uri.port) != null ? _ref2 : (uri.protocol != null ? 80 : this.request.url.port),
        path: ((_ref3 = uri.pathname) != null ? _ref3 : '/') + ((_ref4 = uri.search) != null ? _ref4 : '') + ((_ref5 = uri.hash) != null ? _ref5 : '')
      };
      return http.get(options, function(res) {
        var body;
        body = '';
        res.on('data', __bind(function(chunk) {
          return body += chunk.toString();
        }, this));
        return res.on('end', __bind(function() {
          return callback(src, res.statusCode, body);
        }, this));
      }).on('error', function(e) {
        return callback(src, 500, e.message);
      });
    };
    this.subESI = function(src, body) {
      var re;
      re = new RegExp('<esi[^>]* src=("' + RegExp.escape(src) + '"|\'' + RegExp.escape(src) + '\')[^>]*>(</esi[^>]*>)?', 'gi');
      this.data = this.data.replace(re, body);
      return this.searchESI(this.data).length;
    };
    this.processESIvars = function(data) {
      var esi_var, esi_var_result, esi_vars, i, re;
      re = new RegExp('\\$\\([^\\)]+\\)', 'gi');
      esi_vars = data.match(re);
      for (i in esi_vars) {
        re = new RegExp('\\(([^{\\|\\)]*)({([^}]*)})?(\\|([^\\|{)]*))?\\)', 'i');
        esi_var = esi_vars[i].match(re);
        esi_var_result = this.lookupESIvar(esi_var[1], esi_var[3]);
        if (!esi_var_result && (esi_var[5] != null)) {
          esi_var_result = esi_var[5];
        }
        data = data.replace(esi_vars[i], esi_var_result);
      }
      return data;
    };
    this.lookupESIvar = function(esi_var, options) {
      var cookie, matches, re, result, _ref;
      result = '';
      switch (esi_var.toUpperCase()) {
        case 'HTTP_ACCEPT_LANGUAGE':
          result = this.request['accept-language'];
          break;
        case 'HTTP_COOKIE':
          result = '';
          if (options != null) {
            re = new RegExp('(^| )' + options + '=([^;]*)', 'i');
            cookie = (_ref = this.request['cookie']) != null ? _ref : '';
            matches = cookie.match(re);
            if (matches != null) {
              result = matches[2];
            }
          }
          break;
        case 'HTTP_HEADER':
          result = this.request[options];
          break;
        case 'HTTP_HOST':
          result = this.request['host'];
          break;
        case 'HTTP_REFERER':
          result = this.request['referer'];
          break;
        case 'HTTP_USER_AGENT':
          result = this.request['user-agent'];
          break;
        case 'QUERY_STRING':
          if (options != null) {
            result = this.request.url.query[options];
          } else {
            result = querystring.stringify(this.request.url.query);
          }
      }
      return result != null ? result : '';
    };
    RegExp.escape = function(text) {
      return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    };
  };
}).call(this);

==> connect-esi-0.1.1.tgz: package/lib/connect-esi.js <==
(function() {
  var http, out, querystring, url;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  http = require('http');
  url = require('url');
  querystring = require('querystring');
  out = (require('styout')).instance('connect-esi');
  out.verbosity = out.WARN_VERBOSITY;
  exports.setupESI = function() {
    var handleESI;
    return handleESI = function(req, res, next) {
      var end, endCalled, endWait, write;
      endCalled = false;
      endWait = false;
      /*
      		writeHead = res.writeHead
      		res.writeHead = (statusCode, reasonPhrase, headers) ->
      			out.debug "res.writeHead | statusCode: " + statusCode + " | req.url: " + req.url
      			out.debug res._headers
      			res.writeHead = writeHead
      			res.writeHead statusCode, reasonPhrase, headers
      			return		
      		*/
      write = res.write;
      res.write = function(chunk, encoding) {
        var content_type, esiProcessor;
        res.write = write;
        content_type = (res._headers != null) && (res._headers['content-type'] != null) ? res._headers['content-type'] : 'text/plain';
        if (content_type.indexOf('text') !== -1) {
          out.debug("res.write | content-type: " + content_type + " | req.url: " + req.url);
          endWait = true;
          esiProcessor = new exports.processESI(chunk, function(err, chunk) {
            var _ref;
            out.debug("processESI callback | req.url: " + req.url);
            res.setHeader('content-length', chunk.length);
            res.setHeader('content-type', content_type);
            res.writeHead((_ref = res.statusCode) != null ? _ref : 200);
            endWait = false;
            res.write(chunk, encoding);
            if (endCalled) {
              return res.end();
            }
          });
          esiProcessor.request = req.headers;
          esiProcessor.request.url = url.parse('http://' + req.headers['host'] + req.url, true);
          esiProcessor.execute();
        } else {
          res.write(chunk, encoding);
        }
      };
      end = res.end;
      res.end = function(data, encoding) {
        endCalled = true;
        out.debug("res.end | data: " + (data != null) + " | wait: " + endWait + " | req.url: " + req.url);
        if (data) {
          res.write(data, encoding);
        } else if (endWait === false) {
          res.end = end;
          res.end();
        }
      };
      return next();
    };
  };
  exports.processESI = function(data, callback) {
    this.data = data.toString();
    this.callback = callback;
    this.request = [];
    this.request['url'] = url.parse('http://localhost:5678');
    this.execute = function() {
      var esi_tags, k, src_vars, _results;
      out.info("Searching for ESIs...");
      esi_tags = this.searchESI(this.data);
      out.info("Found " + esi_tags.length + " ESIs");
      if (esi_tags.length !== 0) {
        _results = [];
        for (k in esi_tags) {
          src_vars = this.processESIvars(esi_tags[k]);
          out.info("Fetch ESI: " + src_vars + (esi_tags[k] !== src_vars ? " | Original ESI: " + esi_tags[k] : ""));
          _results.push(this.fetchESI([esi_tags[k], src_vars], __bind(function(src, status, body) {
            var remaining;
            if (status !== 200) {
              body = '';
              out.warn("ESI: " + src[1] + " returned status " + status);
            } else {
              out.debug("ESI: " + src[1] + " returned status " + status);
            }
            out.info("ESI tag subsitution: " + src[0]);
            remaining = this.subESI(src[0], body);
            out.info(remaining + " remaining ESIs");
            if (remaining === 0) {
              return this.callback(false, this.data);
            }
          }, this)));
        }
        return _results;
      } else {
        return this.callback(false, this.data);
      }
    };
    this.searchESI = function(data) {
      var esi_tags, k, match, re, _ref;
      re = new RegExp('<esi[^>]* src=("[^>"]+"|\'[^>\']+\')[^>]*>(</esi[^>]*>)?', 'gi');
      esi_tags = data.match(re);
      for (k in esi_tags) {
        re = new RegExp(' src=("(.*?)"|\'(.*?)\')');
        match = esi_tags[k].match(re);
        esi_tags[k] = (_ref = match[2]) != null ? _ref : match[3];
      }
      return esi_tags != null ? esi_tags : [];
    };
    this.fetchESI = function(src, callback) {
      var options, uri, _ref, _ref2, _ref3, _ref4, _ref5;
      if (!(src instanceof Array)) {
        src = [src, src];
      }
      uri = url.parse(src[1]);
      options = {
        host: (_ref = uri.hostname) != null ? _ref : this.request.url.hostname,
        port: (_ref2 = uri.port) != null ? _ref2 : (uri.protocol != null ? 80 : this.request.url.port),
        path: ((_ref3 = uri.pathname) != null ? _ref3 : '/') + ((_ref4 = uri.search) != null ? _ref4 : '') + ((_ref5 = uri.hash) != null ? _ref5 : '')
      };
      return http.get(options, function(res) {
        var body;
        body = '';
        res.on('data', __bind(function(chunk) {
          return body += chunk.toString();
        }, this));
        return res.on('end', __bind(function() {
          return callback(src, res.statusCode, body);
        }, this));
      }).on('error', function(e) {
        return callback(src, 500, e.message);
      });
    };
    this.subESI = function(src, body) {
      var re;
      re = new RegExp('<esi[^>]* src=("' + RegExp.escape(src) + '"|\'' + RegExp.escape(src) + '\')[^>]*>(</esi[^>]*>)?', 'gi');
      this.data = this.data.replace(re, body.replace(/\$/g, '$$$'));
      return this.searchESI(this.data).length;
    };
    this.processESIvars = function(data) {
      var esi_var, esi_var_result, esi_vars, i, re;
      re = new RegExp('\\$\\([^\\)]+\\)', 'gi');
      esi_vars = data.match(re);
      for (i in esi_vars) {
        re = new RegExp('\\(([^{\\|\\)]*)({([^}]*)})?(\\|([^\\|{)]*))?\\)', 'i');
        esi_var = esi_vars[i].match(re);
        esi_var_result = this.lookupESIvar(esi_var[1], esi_var[3]);
        if (!esi_var_result && (esi_var[5] != null)) {
          esi_var_result = esi_var[5];
        }
        data = data.replace(esi_vars[i], esi_var_result);
      }
      return data;
    };
    this.lookupESIvar = function(esi_var, options) {
      var cookie, matches, re, result, _ref;
      result = '';
      switch (esi_var.toUpperCase()) {
        case 'HTTP_ACCEPT_LANGUAGE':
          result = this.request['accept-language'];
          break;
        case 'HTTP_COOKIE':
          result = '';
          if (options != null) {
            re = new RegExp('(^| )' + options + '=([^;]*)', 'i');
            cookie = (_ref = this.request['cookie']) != null ? _ref : '';
            matches = cookie.match(re);
            if (matches != null) {
              result = matches[2];
            }
          }
          break;
        case 'HTTP_HEADER':
          result = this.request[options];
          break;
        case 'HTTP_HOST':
          result = this.request['host'];
          break;
        case 'HTTP_REFERER':
          result = this.request['referer'];
          break;
        case 'HTTP_USER_AGENT':
          result = this.request['user-agent'];
          break;
        case 'QUERY_STRING':
          if (options != null) {
            result = this.request.url.query[options];
          } else {
            result = querystring.stringify(this.request.url.query);
          }
      }
      return result != null ? result : '';
    };
    RegExp.escape = function(text) {
      return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    };
  };
}).call(this);
